/*
 * @author Andreas Butti
 */

#include <avr/io.h>
#include <util/delay.h>     // for _delay_ms()
#include <avr/interrupt.h>  // for sei()
#include "display.h"

void initTimer() {
	TCCR0B |= (1 << CS00) | (1 << CS01); // Prescaler: 64
	//TCCR0B |= (1 << CS02); // Prescaler: 256
	//TCCR0B |= (1 << CS00) | (1 << CS02); // Prescaler: 1024
	TIMSK0 |= (1 << OCIE0A); // enable interrupt
}

static uint8_t data[3];
static uint8_t index = 0;
/**
 * Main Loop
 */
int main(void) {
	DDRD = (1 << PD0) | (1 << PD5) | (1 << PD6) | (1 << PD7);
	DDRB = 0xff;

	initTimer();
	sei(); // enable interrupts

	data[0] = ~DISP7SEG_CHAR_0;
	data[1] = ~DISP7SEG_CHAR_1;
	data[2] = ~DISP7SEG_CHAR_2;

	uint8_t x = 0;

	while (1) {
		for(uint8_t i = 0; i < 3; i++) {
			data[i] = ~getDigit(i + x);
		}
		x++;
		if(x == 10) {
			x = 0;
		}
		_delay_ms(500);
	}

	return 0;
}

/**
 * Timer interrupt
 */
ISR(TIMER0_COMPA_vect)
{
	PORTD &= ~((1 << PD5) | (1 << PD6) | (1 << PD7));
	PORTD |= (1 << (index + 5));

	PORTB = data[index];

	index++;
	if(index >= sizeof(data) / sizeof(uint8_t)) {
		index = 0;
	}
}
